@@ -3,19 +3,16 @@ import time
 import logging
 import traceback
 
-try:
-    import cPickle as pickle
-except ImportError:
-    import pickle
+import cPickle as pickle
 
 from django.conf import settings
 from django.core.mail import mail_admins
 from django.contrib.auth.models import User
 from django.contrib.sites.models import Site
 
-from lockfile import FileLock, AlreadyLocked, LockTimeout
-
+from notification.lockfile import FileLock, AlreadyLocked, LockTimeout
 from notification.models import NoticeQueueBatch
+from notification.signals import emitted_notices
 from notification import models as notification
 
 # lock timeout value. how long to wait for the lock to become available.
@@ -23,8 +20,11 @@ from notification import models as notification
 LOCK_WAIT_TIMEOUT = getattr(settings, "NOTIFICATION_LOCK_WAIT_TIMEOUT", -1)
 
 
-def send_all():
-    lock = FileLock("send_notices")
+def send_all(*args):
+    if len(args) == 1:
+        lock = FileLock(args[0])
+    else:
+        lock = FileLock("send_notices")
     
     logging.debug("acquiring lock...")
     try:
@@ -37,7 +37,7 @@ def send_all():
         return
     logging.debug("acquired.")
     
-    batches, sent = 0, 0
+    batches, sent, sent_actual = 0, 0, 0
     start_time = time.time()
     
     try:
@@ -45,19 +45,27 @@ def send_all():
         try:
             for queued_batch in NoticeQueueBatch.objects.all():
                 notices = pickle.loads(str(queued_batch.pickled_data).decode("base64"))
-                for user, label, extra_context, on_site, sender in notices:
+                for user, label, extra_context, sender in notices:
                     try:
                         user = User.objects.get(pk=user)
                         logging.info("emitting notice %s to %s" % (label, user))
                         # call this once per user to be atomic and allow for logging to
                         # accurately show how long each takes.
-                        notification.send_now([user], label, extra_context, on_site, sender)
+                        if notification.send_now([user], label, extra_context, sender):
+                            sent_actual += 1
                     except User.DoesNotExist:
                         # Ignore deleted users, just warn about them
                         logging.warning("not emitting notice %s to user %s since it does not exist" % (label, user))
                     sent += 1
                 queued_batch.delete()
                 batches += 1
+            emitted_notices.send(
+                sender=NoticeQueueBatch,
+                batches=batches,
+                sent=sent,
+                sent_actual=sent_actual,
+                run_time="%.2f seconds" % (time.time() - start_time)
+            )
         except:
             # get the exception
             exc_class, e, t = sys.exc_info()
