@@ -1,4 +1,3 @@
-
 """
 lockfile.py - Platform-independent advisory file locks.
 
@@ -53,19 +52,16 @@ from __future__ import division
 import sys
 import socket
 import os
+import thread
 import threading
 import time
 import errno
+import urllib
 
 # Work with PEP8 and non-PEP8 versions of threading module.
-try:
-    threading.current_thread
-except AttributeError:
+if not hasattr(threading, "current_thread"):
     threading.current_thread = threading.currentThread
-try:
-    # python 2.6 has threading.current_thread so we need to do this separately.
-    threading.Thread.get_name
-except AttributeError:
+if not hasattr(threading.Thread, "get_name"):
     threading.Thread.get_name = threading.Thread.getName
 
 __all__ = ['Error', 'LockError', 'LockTimeout', 'AlreadyLocked',
@@ -167,7 +163,8 @@ class LockBase:
         self.hostname = socket.gethostname()
         self.pid = os.getpid()
         if threaded:
-            tname = "%s-" % threading.current_thread().get_name()
+            name = threading.current_thread().get_name()
+            tname = "%s-" % urllib.quote(name, safe="")
         else:
             tname = ""
         dirname = os.path.dirname(self.lock_file)
@@ -238,7 +235,7 @@ class LinkFileLock(LockBase):
         try:
             open(self.unique_name, "wb").close()
         except IOError:
-            raise LockFailed
+            raise LockFailed("failed to create %s" % self.unique_name)
 
         end_time = time.time()
         if timeout is not None and timeout > 0:
@@ -336,7 +333,7 @@ class MkdirFileLock(LockBase):
                     time.sleep(wait)
                 else:
                     # Couldn't create the lock for some other reason
-                    raise LockFailed
+                    raise LockFailed("failed to create %s" % self.lock_file)
             else:
                 open(self.unique_name, "wb").close()
                 return
